@@ -3,7 +3,7 @@ from bluer_sbc.parts.db import db_of_parts
 from bluer_sbc.parts.consts import parts_url_prefix
 
 from bluer_ugv.README.rangin.items import items
-from bluer_ugv.rangin.parts import dict_of_parts
+from bluer_ugv.designs.rangin.parts import dict_of_parts
 from bluer_ugv.README.rangin.consts import rangin_mechanical_design
 
 docs = [
@@ -40,6 +40,16 @@ docs = [
                     "marquee": f"{rangin_mechanical_design}/robot-90.png?raw=true",
                     "url": f"{rangin_mechanical_design}/robot-90.stl",
                 },
+                {
+                    "name": "90 (without the cage)",
+                    "marquee": f"{rangin_mechanical_design}/robot-90-2.png?raw=true",
+                    "url": f"{rangin_mechanical_design}/robot-90.stl",
+                },
+                {
+                    "name": "90c (curved)",
+                    "marquee": f"{rangin_mechanical_design}/robot-90c.png?raw=true",
+                    "url": f"{rangin_mechanical_design}/robot-90c.stl",
+                },
             ]
         ),
     },
