@@ -2,7 +2,6 @@ from bluer_ai.help.generic import help_functions as generic_help_functions
 
 from bluer_ugv import ALIAS
 from bluer_ugv.help.git import help_git
-from bluer_ugv.help.parts import help_functions as help_parts
 from bluer_ugv.help.swallow import help_functions as help_swallow
 
 
@@ -11,7 +10,6 @@ help_functions = generic_help_functions(plugin_name=ALIAS)
 help_functions.update(
     {
         "git": help_git,
-        "parts": help_parts,
         "swallow": help_swallow,
     }
 )
